@@ -8,84 +8,38 @@ use warnings;
 use vars qw($VERSION);
 
 use LWP::UserAgent;
-use HTTP::Headers;
-use Encode;
 
-$VERSION = '0.02';
-
-my $headers = HTTP::Headers->new;
-$headers->header ('Accept-Charset' => 'utf-8;q=0.7,*;q=0.7');
-
-my $lwp_conf = {
-	agent => 'Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.5; en-US; rv:1.9.0.1) Gecko/2008070206 Firefox/3.0.1',
-	default_headers => $headers,
-};
-
-my $regexps = [
-	qr|(?is)<p class="errmsg">.*?<b>[^<]+? &#151; (\d+)|,
-	qr|(?is)<p class="errmsg">.*?<b>[^<]+? 1(\d+).|, # zero -)
-	qr|(?is)<tr valign="top"[^<]+<td class="current".+?\/td>[^<]+(?:<td .+?\/td>[^<]+){2}?<td\D+(\d+)|,
-];
+$VERSION = '0.01';
 
 sub new {
 	my $class = shift;
 	my %par = @_;
 	my $self;
-	
-	# config overrided by parameters
-	my $ua = $self->{ua} = LWP::UserAgent->new;
-	
-	foreach my $k (keys %$lwp_conf) {
-		$ua->$k ($lwp_conf->{$k});
-	}
 
+	$self->{ua} = LWP::UserAgent->new(agent => $par{agent} || 'Bond, James Bond/0.07') or return;
+	$self->{ua}->proxy('http', $par{proxy}) if $par{proxy};
 	bless($self, $class);
 }
 
-sub user_agent {
-	shift->{ua};
-}
-
-sub request_uri {
-	my ($self, $url) = @_;
-
-	my $query = "http://search.yaca.yandex.ru/yca/cy/ch/$url/";
-
-	return $query;
-}
-
 sub get {
-	my ($self, $url) = @_;
+	my ($self, $domain) = @_;
+	return unless defined $domain;
 
-	my $query = $self->request_uri ($url);
-  
-	my $resp = $self->{ua}->get($query);
-	
-	if ($resp->is_success) {
-		
-		my $content = decode_utf8 ($resp->content);
-		
-		my $tic = undef;
-		
-		my $c = 0;
-		
-		foreach my $rx (@$regexps) {
-			if ($content =~ /$rx/) {
-				$tic = $1;
-				last;
-			}
-		}
+	my $resp = $self->{ua}->get(sprintf('http://search.yaca.yandex.ru/yca/cy/ch/%s/', $domain));
 
+	if ($resp->is_success && $resp->content =~ /"http:\/\/www.yandex.ru\/yandsearch\/\?text=&Link=[^"]*$domain[^"]*&ci=(\d+)[^"]*"/i) {
 		if (wantarray) {
-			return ($tic, $resp);
-		} else {
-			return $tic;
+			return ($1, $resp);
 		}
-
-	} else {
+		else {
+			return $1;
+		}
+	}
+	else {
 		if (wantarray) {
 			return (undef, $resp);
-		} else {
+		}
+		else {
 			return;
 		}
 	}
@@ -93,6 +47,7 @@ sub get {
 
 1;
 
+
 __END__
 
 =head1 NAME
@@ -122,20 +77,17 @@ It uses C<LWP::UserAgent> for making request to Google.
 =item  $tic = WWW::Yandex::TIC->new(%options);
 
 This method constructs a new C<WWW::Yandex::TIC> object and returns it.
-
-=item  $ua = $tic->user_agent;
-
-This method returns constructed C<LWP::UserAgent> object.
-You can configure object before making requests. 
-Default configuration described below:
+Key/value pair arguments may be provided to set up the initial state.
+The following options is correspond to attribute methods described below:
 
    KEY                     DEFAULT
    -----------             --------------------
-   agent                   "Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.5; en-US; rv:1.9.0.1) Gecko/2008070206 Firefox/3.0.1"
-   default_headers         "Accept-Charset: utf-8;q=0.7,*;q=0.7"
+   agent                   "Bond, James Bond/0.07"
+   proxy                   undef
 
-C<agent> specifies the header 'User-Agent' when querying Yandex.
-C<default_headers> is a C<HTTP::Headers> object. See C<LWP::UserAgent>.
+C<agent> specifies the header 'User-Agent' when querying Yandex.  If
+the C<proxy> option is passed in, requests will be made through
+specified proxy. 
 
 =back
 
@@ -164,12 +116,10 @@ If you find any, please report ;)
 =head1 AUTHOR
 
 Dmitry Bashlov F<E<lt>bashlov@cpan.orgE<gt>>.
-Ivan Baktsheev F<E<lt>dot.and.thing@gmail.comE<gt>>.
 
 =head1 COPYRIGHT
 
-Copyright 2005, Dmitry Bashlov
-Copyright 2008, Ivan Baktsheev
+Copyright 2005, Dmitry Bashlov, All Rights Reserved.
 
 You may use, modify, and distribute this package under the
 same terms as Perl itself.
